function fv = featureExtraction(fname) 
%fname = '\\lampfs01\lamp\Users\mudit\Lamp\ClutterData\workingDir\00010065.TIF'

% Opening the file
block = imread(fname);

% 0 is black, 1 is white
block = logical(block);
%imshow(block);

block = ~block;
% Now 0 is white, 1 is black (foreground)

[r c] = size(block);
imgArea = r*c;

labOrig = bwlabel(block);

% Performing Half-erosion
dt = bwdist(~block);
maxDist = max(max(dt));
halfEroded = (dt>maxDist/2);

labHE = bwlabel(halfEroded);

%%%%%%%%%%%%%%%%%%%%%%%
% Extracting Features %
%%%%%%%%%%%%%%%%%%%%%%%
CCprops = regionprops(labHE, 'area','perimeter','centroid');

% # of CC
fv(1) = max(max(labHE));

% average size of CC/image Area
areas = cat(1,CCprops.Area);
fv(2) = mean(areas)/imgArea;

% variance in size of CC
fv(3) = std(areas);

% variance in position of CC
centroids = cat(1,CCprops.Centroid);
fv(4) = std(centroids(:,1));
fv(5) = std(centroids(:,2));

% Area/Perimeter
perimeters = cat(1,CCprops.Perimeter);
meanP = mean(perimeters)/imgArea;
fv(6) = fv(2)/meanP;

% Ratio of CC left after half-erosion
fv(7) = max(max(labOrig))/fv(1);

fv = fv';
